// Specify actions or filters for incoming or outgoing OSC messages
// Use the "app.on" functions for custom actions e.g. when the session has started.

var sendTargets = settings.read('send') // array of "ip:port" strings
var [sendHost, sendPort] = sendTargets[0].split(':')

// this will be executed when your session starts
app.on('sessionOpened', (data, client)=>{
    send(sendHost,sendPort,'/SetList/GetSongList')
	send(sendHost,sendPort,'/SelectSongByIndex', 0)
})

module.exports = {
	
    init: function(){
        // this will be executed once when the osc server starts

		// switch to the Gig Performer setlist view
        send(sendHost,sendPort,'/Actions/SetlistView')
        
        /*
        // example delaying an OSC request
        setTimeout(function(){ 
			send(sendHost,sendPort,'/SetList/GetSongList')
		}, 1000);
		*/
    },
    
    oscInFilter:function(data){
        // Filter incoming osc messages

        var {address, args, host, port} = data

        // address = string
        // args = array of {value, type} objects
        // host = string
        // port = integer
        
        // if a setlist change is detected, request the list of songs
        if (address == '/SetListChanged') {
        	send(sendHost,sendPort,'/SetList/GetSongList')	
        };

        // calculate the number of songs, and update the 'song_count' variable used in the main layout   
        if (address.match(/\/SongName/gm)) {
        	var num = address.replace(/[^0-9]/gm,'')
        	receive('/SET', 'song_count', parseInt(num)+1)
        };
        
        // calculate the number of song parts, and update the 'songpt_count' variable used in the main layout 
        if (address.match(/\/SongPart[0-9]+Name/gm)) {
        	var num = address.replace(/[^0-9]/gm,'')
        	receive('/SET', 'songpt_count', parseInt(num)+1)
        };
        // return data if you want the message to be processed
        return {address, args, host, port}

    },

    oscOutFilter:function(data){
        // Filter outgoing osc messages

        var {address, args, host, port, clientId} = data

        // same as oscInFilter

        // return data if you want the message to be sent
        return {address, args, host, port}
    },

    unload: function(){
        // this will be executed when the custom module is reloaded
    },

}